@@ -50,6 +50,6 @@ func TestNewServiceAccount(t *testing.T) {
 	got := MakeServiceAccount(obj, testName)
 
 	if diff := cmp.Diff(want, got); diff != "" {
-		t.Errorf("unexpected condition (-want, +got) = %v", diff)
+		t.Error("unexpected condition (-want, +got) =", diff)
 	}
 }
